
netR is a customizable [HTTP](https://developer.mozilla.org/en-US/docs/Web/HTTP) framework for [python](https://www.python.org/). netR is designed for Python users who want more control and customization. netR is composed from the ground up to ensure speed efficiency.

netR is a new [python](https://www.python.org/) framework that need much more development and [feedback](https://github.com/Net-Dash/netR/issues). netR is currently not recommended for production use until version 1.0.0 is released.

# Installing

```shell
$ pip install netR
```

# Docs

- ## Creating a simple HTTP server
    -  ```python
       import netR

       ```
